source("modules/Loading/Loading.R")
source("modules/Calibration/Calibration.R")
source("modules/Anomalies/Anomalies.R")
source("modules/Skill/Skill.R")
source("modules/Saving/Saving.R")
source("modules/Visualization/Visualization.R")

recipe_file <- "modules/Loading/testing_recipes/recipe_seasonal-tests.yml"
recipe <- prepare_outputs(recipe_file)

# Load datasets
data <- load_datasets(recipe)
# Calibrate datasets
calibrated_data <- calibrate_datasets(recipe, data)
# Compute anomalies
calibrated_data <- compute_anomalies(recipe, calibrated_data)
# Compute skill metrics 
skill_metrics <- compute_skill_metrics(recipe, calibrated_data)
# Compute percentiles and probability bins
probabilities <- compute_probabilities(recipe, calibrated_data)
# Export all data to netCDF
save_data(recipe, calibrated_data, skill_metrics, probabilities)
# Plot data
plot_data(recipe, calibrated_data, skill_metrics, probabilities,
	  significance = T)
